<?php

class wdcWhoisFunc {

	private  $error_reporting;
	public function __construct($debug = true) {
		if ( $debug ) {
			error_reporting(E_ALL);
			$error_reporting = true;
		} else {
			error_reporting(0);
			$error_reporting = false;
		}

	}
	public $arrContextOptions = array(
			"ssl"=>array(
				"verify_peer"=>false,
				"verify_peer_name"=>false,
			),
		);

	public function load_whois_file($file) {
		$file_dir = plugin_dir_path(__FILE__) . $file;
		$file_content = file_get_contents($file_dir);
		
		return $file_content !== false ? $file_content : null;
	}

	public function get_sld_tld($domain) {
		list($sld, $tld) = explode('.', $domain, 2);
		$d = array(
			'domain' => $domain,
			'sld' => $sld,
			'tld' => $tld
		);

		return $d;
	}

	public function parse_domain($domain) {
		$whois = json_decode($this->load_whois_file('whois.json'), true);
		if ($whois === null) {
			return false; // Unable to parse the JSON file
		}
	
		$dom = strtolower($domain);
		$port = 43;
		$method = 1; // 1 = whois server based, 2 = http(s)
	
		$titan = TitanFramework::getInstance('wdc-options');
		$dom = $this->get_sld_tld($dom);
		$domain = $dom['domain'];
		$sld = $dom['sld'];
		$tld = $dom['tld'];
	
		if (isset($whois['whoisServers'][$tld][0])) {
			[$whois_server, $available_string] = $whois['whoisServers'][$tld];
		} else {
			return false;
		}
	
		if (function_exists('parse_ini_string')) {
			$wdc_config = parse_ini_string($titan->getOption('wdc_config'), true);
		} else {
			$wdc_config = wdc_parse_ini_string_m($titan->getOption('wdc_config'), true);
		}
	
		if ($wdc_config && isset($wdc_config['WhoisServer'][$tld]['uri'], $wdc_config['WhoisServer'][$tld]['string'])) {
			$whois_server = $wdc_config['WhoisServer'][$tld]['uri'];
			$available_string = $wdc_config['WhoisServer'][$tld]['string'];
		}
	
		if (strpos($whois_server, "http://") !== false || strpos($whois_server, "https://") !== false) {
			$method = 2;
		}
	
		if ($tld === 'ch') {
			$port = 4343;
		}
	
		return [
			'domain' => $domain,
			'sld' => $tld,
			'tld' => $sld,
			'whois_server' => $whois_server,
			'port' => $port,
			'method' => $method,
			'available_string' => $available_string
		];
	}

	public function is_available($domain_name) {
		$titan = TitanFramework::getInstance('wdc-options');
		$available_domain_cache_time = $titan->getOption('available_domain_cache');
		$unavailable_domain_cache_time = $titan->getOption('unavailable_domain_cache');
	
		$parsed_domain = $this->parse_domain($domain_name);
		if (!$parsed_domain) {
			return json_encode(array('status' => 2, 'protocol' => '', 'response' => ''));
		}
	
		$timeout = 5;
		$domain = $parsed_domain['domain'];
		$tld = $parsed_domain['sld'];
		$whois_server = $parsed_domain['whois_server'];
		$port = $parsed_domain['port'];
		$method = $parsed_domain['method'];
		$available_string = $parsed_domain['available_string'];
	
		if ($method === 2) {
			$check = $this->whois_lookup(2, $whois_server, $port, $domain, $timeout);
			$status = preg_match('/' . $available_string . '/', $check) ? 1 : 0;
			return json_encode(array('status' => $status, 'protocol' => 'http', 'response' => $check));
		}
	
		$specialTLDs = ['co.zw', 'org.zw', 'ac.zw', 'gov.zw', 'mil.zw', 'zw'];
		if (in_array($tld, $specialTLDs)) {
			$zw_domain = $this->whois_lookup(3, $whois_server, $port, $domain, $timeout);
			$status = $zw_domain ? 0 : 1;
			return json_encode(array('status' => $status, 'protocol' => 'dns', 'response' => $zw_domain));
		}
	
		$response = $this->whois_lookup(1, $whois_server, $port, $domain, $timeout);
	
		if (is_object($response)) {
			return json_encode(array('status' => $response->status, 'protocol' => $response->protocol, 'response' => $response->whois));
		}
	
		$customTLDs = ['bo', 'com.bo', 'org.bo', 'net.bo', 'tv.bo', 'web.bo'];
		if (in_array($tld, $customTLDs)) {
			$status = strpos($response, $available_string) === false ? 1 : 0;
			return json_encode(array('status' => $status, 'protocol' => 'custom', 'response' => $response));
		}
	
		$cacheKey = 'wdc_' . $domain_name;
		if (is_string($response) && strpos($response, $available_string) !== false) {
			$responseContainsString = true;
		} else {
			$responseContainsString = false;
		}
		$cacheTime = $responseContainsString ? $available_domain_cache_time : $unavailable_domain_cache_time;
	
		if (!empty($response) && $cacheTime && !get_transient($cacheKey)) {
			set_transient($cacheKey, $response, $cacheTime);
		}
	
		$status = $responseContainsString ? 1 : 0;
		return json_encode(array('status' => $status, 'protocol' => $port, 'response' => $response));
	}

	public function whois_lookup($method, $whois_server, $port, $domain_name, $timeout) {
		if ($method === 1) {
			$transient = get_transient('wdc_' . $domain_name);
			if (!empty($transient)) {
				return $transient;
			} else {
				$response = $this->perform_fsockopen($whois_server, $port, $domain_name, $timeout);
			}
		} elseif ($method === 2) {
			$response = wp_remote_get($whois_server . $domain_name, array('timeout' => $timeout));
			if (!is_wp_error($response)) {
				$response = wp_remote_retrieve_body($response);
			} else {
				$response = '';
			}
		} elseif ($method === 3) {
			$response = dns_get_record($domain_name, DNS_NS);
		} elseif ($method === 4) {
			$response = $this->perform_customFsockopen($whois_server, $port, $domain_name, $timeout);
		} else {
			return '';
		}
	
		return $response;
	}
	
	private function perform_fsockopen($whois_server, $port, $domain_name, $timeout){
		$args = [
			'headers' => [
				'User-Agent' => 'WordPress-WP-Domain-Checker'
			]
		];
	
		$response = false;
	
		$con = fsockopen($whois_server, $port, $errno, $errstr, $timeout);
		if ($con !== false) {
			stream_set_timeout($con, $timeout);
			$response = $this->getResponseFromSocket($con, $domain_name);
			fclose($con);
		}
	
		if (!$response) {
			// Fallback to wp_remote_get with custom User-Agent if fsockopen fails or times out
			$wp_remote_response = wp_remote_get("https://api.wpdomainchecker.com/whois/$domain_name", $args);
			
			if (!is_wp_error($wp_remote_response) && wp_remote_retrieve_response_code($wp_remote_response) === 200) {
				return json_decode(wp_remote_retrieve_body($wp_remote_response));
			} else {
				return null; // Handle error condition appropriately
			}
		}
	
		return $response;
	}
	
	private function perform_customFsockopen($whois_server, $port, $domain_name, $timeout){
		$response = '';
		$con = fsockopen($whois_server[0], $port, $errno, $errstr, $timeout);
		if ($con) {
			$response .= $this->getResponseFromSocket($con, "n + " . $domain_name);
			fclose($con);
		}
	
		$con = fsockopen($whois_server[1], $port, $errno, $errstr, $timeout);
		if ($con) {
			$response .= $this->getResponseFromSocket($con, $domain_name);
			fclose($con);
		}
	
		return $response;
	}
	
	private function getResponseFromSocket($con, $domain_name){
		$response = '';
		fputs($con, $domain_name . "\r\n");
		while (($buffer = fgets($con, 128)) !== false) {
			$response .= $buffer;
		}
		if (!feof($con)) {
			return false;
		}
		return $response;
	}

	public function whois_lookup_ip($domain){
		$timeout = 10;
		$whois_servers = json_decode($this->load_whois_file('whois.json'), true);
		if (isset($whois_servers['whoisServers']['ipv4'][0]) && isset($whois_servers['whoisServers']['ipv4'][1])) {
			$whois_server = array($whois_servers['whoisServers']['ipv4'][0], $whois_servers['whoisServers']['ipv4'][1]);
		}else{
			$whois_server = array("whois.arin.net", "whois.apnic.net");
		}
		$port = 43;
		$method = 4;
		$response = __("IP Address Whois Lookup not available for this IP Address.","wdc");

		$response = $this->whois_lookup($method, $whois_server, $port, $domain, $timeout);
		if(is_object($response)){
			$response = $response->whois;
		}

		return $response;
	}
	public function whois_lookup_details($domain){
		$d = $this->parse_domain($domain);
		$timeout = 10;
		$domain = $d['domain'];
		$whois_server = $d['whois_server'];
		$port = $d['port'];
		$method = $d['method'];
		$response = __("Domain Whois Lookup not available for this domain.","wdc");
		 if($method === 1){
		 	$response = $this->whois_lookup(1, $whois_server, $port, $domain, $timeout);
			if(is_object($response)){
				$response = $response->whois;
			}
		}

		return $response;
	}

}
